summaryrefslogtreecommitdiff
path: root/ai
diff options
context:
space:
mode:
authortruelight <truelight@openttd.org>2005-12-14 15:54:23 +0000
committertruelight <truelight@openttd.org>2005-12-14 15:54:23 +0000
commit6ca528ec82cc26175657d35c53f9ca16e73f92cf (patch)
tree9c70f6e80706def809d03cffd8aafe58ca6444d9 /ai
parent607e518ab80aa3a8a29c4e7d94a93a1817615ee5 (diff)
downloadopenttd-6ca528ec82cc26175657d35c53f9ca16e73f92cf.tar.xz
(svn r3305) -Rename: Changed all instances of ottd_ related to the AI to ttai_
Diffstat (limited to 'ai')
-rw-r--r--ai/ai.c20
-rw-r--r--ai/ai_event.h26
2 files changed, 23 insertions, 23 deletions
diff --git a/ai/ai.c b/ai/ai.c
index a66a42123..ffb5cccc3 100644
--- a/ai/ai.c
+++ b/ai/ai.c
@@ -240,7 +240,7 @@ void AI_CommandResult(bool succeeded)
if (_ai_current_uid == 0)
return;
- ai_event(_current_player, succeeded ? ottd_Event_CommandSucceeded : ottd_Event_CommandFailed, _ai_current_tile);
+ ai_event(_current_player, succeeded ? ttai_Event_CommandSucceeded : ttai_Event_CommandFailed, _ai_current_tile);
}
/**
@@ -335,34 +335,34 @@ void AI_ShutdownAIControl(bool with_error)
}
}
-void (*ottd_GetNextAIData)(char **library, char **param);
-void (*ottd_SetAIParam)(char *param);
+void (*ttai_GetNextAIData)(char **library, char **param);
+void (*ttai_SetAIParam)(char *param);
void AI_LoadAIControl(void)
{
/* Load module */
- _ai.gpmi_mod = gpmi_mod_load("ottd_ai_control_mod", NULL);
+ _ai.gpmi_mod = gpmi_mod_load("ttai_control_mod", NULL);
if (_ai.gpmi_mod == NULL) {
AI_ShutdownAIControl(true);
return;
}
/* Load package */
- if (gpmi_pkg_load("ottd_ai_control_pkg", 0, NULL, NULL, &_ai.gpmi_pkg)) {
+ if (gpmi_pkg_load("ttai_control_pkg", 0, NULL, NULL, &_ai.gpmi_pkg)) {
AI_ShutdownAIControl(true);
return;
}
/* Now link all the functions */
{
- ottd_GetNextAIData = gpmi_pkg_resolve(_ai.gpmi_pkg, "ottd_GetNextAIData");
- ottd_SetAIParam = gpmi_pkg_resolve(_ai.gpmi_pkg, "ottd_SetAIParam");
+ ttai_GetNextAIData = gpmi_pkg_resolve(_ai.gpmi_pkg, "ttai_GetNextAIData");
+ ttai_SetAIParam = gpmi_pkg_resolve(_ai.gpmi_pkg, "ttai_SetAIParam");
- if (ottd_GetNextAIData == NULL || ottd_SetAIParam == NULL)
+ if (ttai_GetNextAIData == NULL || ttai_SetAIParam == NULL)
AI_ShutdownAIControl(true);
}
- ottd_SetAIParam(_ai.gpmi_param);
+ ttai_SetAIParam(_ai.gpmi_param);
}
/**
@@ -391,7 +391,7 @@ void AI_StartNewAI(PlayerID player)
char *library = NULL;
char *params = NULL;
- ottd_GetNextAIData(&library, &params);
+ ttai_GetNextAIData(&library, &params);
gpmi_error_stack_enable = 1;
if (library != NULL) {
diff --git a/ai/ai_event.h b/ai/ai_event.h
index 81aa9e89a..65812293d 100644
--- a/ai/ai_event.h
+++ b/ai/ai_event.h
@@ -31,7 +31,7 @@
/* To make our life a bit easier; you now only have to define new
* events here, and automaticly they work in OpenTTD without including
* the ottd_event package. Just because of some lovely macro-shit ;) */
#ifdef DEF_EVENTS
# define DEF_EVENTS
# define INITIAL_SET = -1
@@ -41,24 +41,24 @@
#endif /* DEF_EVENTS */
/* ------------ All available events -------------- */
-DEF_EVENTS int ottd_Event_CommandFailed INITIAL_SET; // (tile, unique_id)
-DEF_EVENTS int ottd_Event_CommandSucceeded INITIAL_SET; // (tile, unique_id)
+DEF_EVENTS int ttai_Event_CommandFailed INITIAL_SET; // (tile, unique_id)
+DEF_EVENTS int ttai_Event_CommandSucceeded INITIAL_SET; // (tile, unique_id)
-DEF_EVENTS int ottd_Event_BuildStation INITIAL_SET; // (station_index, station_tile)
-DEF_EVENTS int ottd_Event_BuildRoadStation INITIAL_SET; // (station_index, station_tile)
+DEF_EVENTS int ttai_Event_BuildStation INITIAL_SET; // (station_index, station_tile)
+DEF_EVENTS int ttai_Event_BuildRoadStation INITIAL_SET; // (station_index, station_tile)
-DEF_EVENTS int ottd_Event_BuildDepot INITIAL_SET; // (depot_index, depot_tile)
-DEF_EVENTS int ottd_Event_BuildRoadDepot INITIAL_SET; // (depot_index, depot_tile)
+DEF_EVENTS int ttai_Event_BuildDepot INITIAL_SET; // (depot_index, depot_tile)
+DEF_EVENTS int ttai_Event_BuildRoadDepot INITIAL_SET; // (depot_index, depot_tile)
-DEF_EVENTS int ottd_Event_BuildVehicle INITIAL_SET; // (vehicle_index, depot_tile)
-DEF_EVENTS int ottd_Event_BuildRoadVehicle INITIAL_SET; // (vehicle_index, depot_tile)
+DEF_EVENTS int ttai_Event_BuildVehicle INITIAL_SET; // (vehicle_index, depot_tile)
+DEF_EVENTS int ttai_Event_BuildRoadVehicle INITIAL_SET; // (vehicle_index, depot_tile)
-DEF_EVENTS int ottd_Event_VehicleEnterDepot INITIAL_SET; // (vehicle_index, depot_tile)
-DEF_EVENTS int ottd_Event_RoadVehicleEnterDepot INITIAL_SET; // (vehicle_index, depot_tile)
+DEF_EVENTS int ttai_Event_VehicleEnterDepot INITIAL_SET; // (vehicle_index, depot_tile)
+DEF_EVENTS int ttai_Event_RoadVehicleEnterDepot INITIAL_SET; // (vehicle_index, depot_tile)
-DEF_EVENTS int ottd_Event_GiveOrder INITIAL_SET; // (vehicle_index)
+DEF_EVENTS int ttai_Event_GiveOrder INITIAL_SET; // (vehicle_index)
-DEF_EVENTS int ottd_Event_BuildRoad INITIAL_SET; // (road_tile, road_pieces)
+DEF_EVENTS int ttai_Event_BuildRoad INITIAL_SET; // (road_tile, road_pieces)
/* ----------------- End of list ------------------ */
#endif /* AI_EVENT */
@@ -31,7 +31,7 @@
/* To make our life a bit easier; you now only have to define new
* events here, and automaticly they work in OpenTTD without including
- * the ottd_event package. Just because of some lovely macro-shit ;) */
+ * the ttai_event package. Just because of some lovely macro-shit ;) */
#ifdef DEF_EVENTS
# define DEF_EVENTS